@@ -1,12 +1,12 @@
 package File::Trash::FreeDesktop;
 
-our $DATE = '2014-12-05'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Fcntl;
 use File::MoreUtil qw(file_exists l_abs_path);
@@ -332,7 +332,7 @@ File::Trash::FreeDesktop - Trash files
 
 =head1 VERSION
 
-This document describes version 0.17 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2014-12-05.
+This document describes version 0.18 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -563,7 +563,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Trash
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-File-Trash-FreeDesktop>.
+Source repository is at L<https://github.com/sharyanto/perl-File-Trash-FreeDesktop>.
 
 =head1 BUGS
 
@@ -579,7 +579,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
